@@ -6,6 +6,8 @@ our $VERSION = '1.000';
 __PACKAGE__->init();
 1;
 
+=encoding iso-8859-1
+
 =head1 NAME
 
 Acme::MetaSyntactic::buffy - The Buffy theme
@@ -19,10 +21,35 @@ Courtesy of L<http://buffyology.johnhorner.nu/>.
 
 Rafael Garcia-Suarez.
 
-Introduced in Acme-MetaSyntactic version 0.09, published on February 7, 2005.
+=head1 CHANGES
 
-Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
-published on May 7, 2012.
+=over 4
+
+=item *
+
+2012-05-07 - v1.000
+
+Received its own version number in Acme-MetaSyntactic-Themes version 1.000.
+
+=item *
+
+2006-05-31
+
+Mail from John Horner informing of the new address of the buffyology web site.
+
+=item *
+
+2005-02-07
+
+Introduced in Acme-MetaSyntactic version 0.09.
+
+=item *
+
+2005-02-04
+
+List proposed by Rafal Garcia-Suarez.
+
+=back
 
 =head1 SEE ALSO
 
