@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::debian;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 __PACKAGE__->init();
 1;
 
@@ -27,6 +27,13 @@ Philippe Bruhat (Book).
 
 =item *
 
+2019-07-29 - v1.004
+
+Added C<bullseye> and C<bookworm> to the list of Debiam codenames.
+Published in Acme-MetaSyntactic-Themes version 1.053.
+
+=item *
+
 2018-10-29 - v1.003
 
 Added C<buster> to the list of Debian codenames.
@@ -74,4 +81,5 @@ hamm slink potato
 woody sarge etch
 lenny squeeze wheezy
 jessie stretch buster
+bullseye bookworm
 sid
