@@ -25,15 +25,35 @@ L<http://www.sergioaragones.com/>.
 
 Philippe "BooK" Bruhat.
 
-Introduced in Acme-MetaSyntactic version 0.27, published on June 21, 2005.
+=head1 CHANGES
 
-Corrected a typo in version 0.82, published on July 10, 2006.
+=over 4
 
-Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
-published on May 7, 2012.
+=item *
 
-Updated with an C<=encoding> pod command in version 1.001,
-published on May 14,2012
+2012-05-14 - v1.001
+
+Updated with an C<=encoding> pod command in version 1.001.
+
+=item *
+
+2012-05-07 - v1.000
+
+Received its own version number in Acme-MetaSyntactic-Themes version 1.000.
+
+=item *
+
+2006-07-10
+
+Corrected a typo in Acme-MetaSyntactic version 0.82.
+
+=item *
+
+2005-06-21
+
+Introduced in Acme-MetaSyntactic version 0.27.
+
+=back
 
 =head1 SEE ALSO
 
