@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::iata;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.005';
+our $VERSION = '1.006';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -33,6 +33,12 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2019-10-28 - v1.006
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.054.
+
+=item *
+
 2019-07-29 - v1.005
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.053.
@@ -338,7 +344,7 @@ LPT LPU LPW LPX LPY LQK LQM LQN LRA LRB LRC LRD LRE LRF LRG LRH LRI LRJ
 LRK LRL LRM LRN LRO LRQ LRR LRS LRT LRU LRV LRX LSA LSB LSC LSD LSE LSF
 LSH LSI LSJ LSK LSL LSM LSN LSO LSP LSR LSS LST LSU LSV LSW LSX LSY LSZ
 LTA LTB LTC LTD LTF LTG LTH LTI LTK LTL LTM LTN LTO LTQ LTR LTS LTT LTV
-LTW LTX LUA LUB LUC LUD LUE LUF LUG LUH LUI LUJ LUK LUL LUM LUN LUO LUP
+LTW LUA LUB LUC LUD LUE LUF LUG LUH LUI LUJ LUK LUL LUM LUN LUO LUP
 LUQ LUR LUS LUT LUU LUV LUW LUX LUY LUZ LVA LVB LVD LVI LVK LVL LVM LVO
 LVP LVS LVX LWA LWB LWC LWE LWI LWK LWL LWM LWN LWO LWR LWS LWT LWV LWX
 LWY LXA LXG LXI LXN LXR LXS LXU LXV LYA LYB LYC LYE LYG LYH LYI LYK LYN
