@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::icao;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.006';
+our $VERSION = '1.007';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -33,6 +33,12 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2019-07-29 - v1.007
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.053.
+
+=item *
+
 2018-10-29 - v1.006
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.052.
@@ -482,7 +488,7 @@ LSGL LSGN LSGS LSME LSMP LSMU LSZA LSZB LSZF LSZH LSZR LSZS LTAB LTAC
 LTAD LTAE LTAF LTAG LTAH LTAI LTAJ LTAK LTAN LTAP LTAQ LTAR LTAS LTAT
 LTAU LTAV LTAW LTAY LTBA LTBD LTBE LTBF LTBG LTBH LTBI LTBJ LTBL LTBM
 LTBO LTBQ LTBR LTBS LTBT LTBU LTBV LTCA LTCC LTCD LTCE LTCF LTCG LTCH
-LTCI LTCJ LTCK LTCL LTFA LTFE LTFJ LUBL LUCH LUCL LUCM LUKK LUSR LUTG
+LTCI LTCJ LTCK LTCL LTFA LTFE LTFJ LTFM LUBL LUCH LUCL LUCM LUKK LUSR LUTG
 LUTR LWOH LWSK LXGB LYBE LYNI LYPG LYTI LYTV LYVR LZBB LZHL LZIB LZKC
 LZKS LZKZ LZLU LZMA LZMC LZNI LZNZ LZOC LZPE LZPP LZPT LZPW LZRU LZRY
 LZSE LZSK LZSL LZSV LZTB LZTR LZTT LZVB LZZI MBAC MBGT MBMC MBNC MBPI
